## 新闻联播

接口：cctv_news

描述：获取新闻联播文字稿数据，数据开始于2006年6月，超过12年历史

限量：可根据日期参数循环提取，总量不限制

积分：本接口需单独开权限（跟积分没关系），具体请参阅权限说明 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期（输入格式：YYYYMMDD 比如：20181211） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| title | str | Y | 标题 |
| content | str | Y | 内容 |

接口调用

```python
pro = ts.pro_api()

df = pro.cctv_news(date='20181211')
```







数据样例

我们对新闻联播进行了分段处理，即每一个大段都加了标题处理，便于大家选择和过滤，也可以合成到一起进行分析。

```python
content  
0   中共中央党史和文献研究院编辑的《习近平谈“一带一路”》一书，已由中央文献出版社出版，即日起在...  
1   习近平总书记视察北京时强调，要坚持人民城市为人民，以北京市民最关心的问题为导向，对大气污染、...  
2   中共中央政治局常委、全国政协主席、中央代表团团长汪洋，11日率中央代表团一分团在南宁看望慰问...  
3   近日，国务院办公厅印发《关于国家综合性消防救援车辆悬挂应急救援专用号牌有关事项的通知》，对应...  
4   改革开放40年，我国对外贸易实现历史性跨越，外商投资环境持续改善，对外投资合作深入推进。今天...  
5   正在国家博物馆举行的伟大的变革--庆祝改革开放40周年大型展览，用一个个你我小家的变化，记录...  
6   为隆重庆祝改革开放40周年，全方位展示改革开放波澜壮阔的伟大历程，由中央宣传部、中央改革办、...  
7   发展与改革的目标，是让百姓有幸福、得实惠。在广西，连续推进的民生建设，把改善人民生活、增进百...  
8   国务院新闻办公室今天就“改革开放与知识产权事业发展”举行中外记者见面会，国家知识产权领域代表...  
9   三季度国家重大政策措施落实情况跟踪审计结果发布三季度国家重大政策措施落实情况跟踪审计结果10...  
10  10日，在波兰卡托维兹举行的联合国气候变化大会期间，由中国发起成立的全球能源互联网发展合作组...  
11  英国议会下院原定于11日就英国政府与欧盟此前达成的“脱欧”协议草案进行投票表决，不过英国首相...  
12  乌将终止《乌俄友好条约》 俄表遗憾乌克兰总统波罗申科10日签署了关于乌方决定不再延长《乌俄友...
```